==> json-schema-validator-1.99.10-sources.jar: com/github/fge/jsonschema/processors/validation/ValidationContextEquivalence.java <==
/*
 * Copyright (c) 2013, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.fge.jsonschema.processors.validation;

import com.github.fge.jsonschema.processors.data.ValidationContext;
import com.github.fge.jsonschema.tree.SchemaTree;
import com.github.fge.jsonschema.util.equivalence.SchemaTreeEquivalence;
import com.google.common.base.Equivalence;

public final class ValidationContextEquivalence
    extends Equivalence<ValidationContext>
{
    private static final Equivalence<ValidationContext> INSTANCE
        = new ValidationContextEquivalence();

    private static final Equivalence<SchemaTree> TREE_EQUIVALENCE
        = SchemaTreeEquivalence.getInstance();

    public static Equivalence<ValidationContext> getInstance()
    {
        return INSTANCE;
    }

    @Override
    protected boolean doEquivalent(final ValidationContext a,
        final ValidationContext b)
    {
        return TREE_EQUIVALENCE.equivalent(a.getSchema(), b.getSchema())
            && a.getInstanceType() == b.getInstanceType();
    }

    @Override
    protected int doHash(final ValidationContext t)
    {
        return 31 * TREE_EQUIVALENCE.hash(t.getSchema())
            + t.getInstanceType().hashCode();
    }
}

==> json-schema-validator-1.99.11-sources.jar: com/github/fge/jsonschema/processors/validation/ValidationContextEquivalence.java <==
/*
 * Copyright (c) 2013, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.github.fge.jsonschema.processors.validation;

import com.github.fge.jsonschema.processors.data.SchemaContext;
import com.github.fge.jsonschema.tree.SchemaTree;
import com.google.common.base.Equivalence;

public final class ValidationContextEquivalence
    extends Equivalence<SchemaContext>
{
    private static final Equivalence<SchemaContext> INSTANCE
        = new ValidationContextEquivalence();

    private static final Equivalence<SchemaTree> TREE_EQUIVALENCE
        = SchemaTreeEquivalence.getInstance();

    public static Equivalence<SchemaContext> getInstance()
    {
        return INSTANCE;
    }

    @Override
    protected boolean doEquivalent(final SchemaContext a, final SchemaContext b)
    {
        return TREE_EQUIVALENCE.equivalent(a.getSchema(), b.getSchema())
            && a.getInstanceType() == b.getInstanceType();
    }

    @Override
    protected int doHash(final SchemaContext t)
    {
        return 31 * TREE_EQUIVALENCE.hash(t.getSchema())
            + t.getInstanceType().hashCode();
    }
}
